/*
 * Copyright Contributors to the fusa-gcc-plugin project
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#include "gcc-plugin.h"
#include "diagnostic-core.h"

#include "distribution.hpp"
#include "process.hpp"

namespace distribution {
vector<string> get_sigkeys_per_package(string package) {
  vector<string> keys = {};

  process::result result = process::run_command({"/usr/bin/rpm", "-q", "--qf", "%{SIGPGP:pgpsig}", package});

  for (string &sig : result.stdout) {
    auto key_start = sig.rfind(rpm_key_needle);

    if (key_start != string::npos)
      keys.push_back(sig.substr(key_start + rpm_key_needle.size()));
  }

  return keys;
}

bool is_distribution_file(const char *path) {
    process::result result =
        process::run_command({"/usr/bin/rpm", "-qf", path});

    if (result.exit_code == 0) {
      vector<string> keys = get_sigkeys_per_package(result.stdout[0]);

      for (string &key : keys)
        if (rh_keys.find(key) != rh_keys.end())
          return true;

      inform((location_t)0,
             "Package '%s' owning the imported path '%s' is signed with an "
             "unknown "
             "key '%s'",
             result.stdout[0].c_str(), path,
             keys.size() != 0 ? keys.at(0).c_str() : "no key");
    }

    return false;
}
}; // namespace distribution
